@@ -57,7 +57,7 @@ class PackageBuild:
         logger.info('{} install'.format(self.name))
         a = run_shell("git remote -v", printf=False)
         git_url = a.split('\n')[0].split('\t')[1].split(' ')[0]
-        run_shell_list(['pip install git+{}'.format(git_url), ])
+        run_shell_list(['pip install -q git+{}'.format(git_url), ])
 
     def git_clear_build(self):
         logger.info('{} build clear'.format(self.name))
